@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from typing import MutableMapping, MutableSequence
+
 from google.rpc import status_pb2  # type: ignore
 import proto  # type: ignore
 
@@ -53,20 +55,20 @@ class YumArtifact(proto.Message):
         BINARY = 1
         SOURCE = 2
 
-    name = proto.Field(
+    name: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    package_name = proto.Field(
+    package_name: str = proto.Field(
         proto.STRING,
         number=2,
     )
-    package_type = proto.Field(
+    package_type: PackageType = proto.Field(
         proto.ENUM,
         number=3,
         enum=PackageType,
     )
-    architecture = proto.Field(
+    architecture: str = proto.Field(
         proto.STRING,
         number=4,
     )
@@ -77,18 +79,18 @@ class ImportYumArtifactsGcsSource(proto.Message):
     reside.
 
     Attributes:
-        uris (Sequence[str]):
+        uris (MutableSequence[str]):
             Cloud Storage paths URI (e.g., gs://my_bucket//my_object).
         use_wildcards (bool):
             Supports URI wildcards for matching multiple
             objects from a single URI.
     """
 
-    uris = proto.RepeatedField(
+    uris: MutableSequence[str] = proto.RepeatedField(
         proto.STRING,
         number=1,
     )
-    use_wildcards = proto.Field(
+    use_wildcards: bool = proto.Field(
         proto.BOOL,
         number=2,
     )
@@ -110,13 +112,13 @@ class ImportYumArtifactsRequest(proto.Message):
             artifacts will be imported.
     """
 
-    gcs_source = proto.Field(
+    gcs_source: "ImportYumArtifactsGcsSource" = proto.Field(
         proto.MESSAGE,
         number=2,
         oneof="source",
         message="ImportYumArtifactsGcsSource",
     )
-    parent = proto.Field(
+    parent: str = proto.Field(
         proto.STRING,
         number=1,
     )
@@ -136,13 +138,13 @@ class ImportYumArtifactsErrorInfo(proto.Message):
             The detailed error status.
     """
 
-    gcs_source = proto.Field(
+    gcs_source: "ImportYumArtifactsGcsSource" = proto.Field(
         proto.MESSAGE,
         number=1,
         oneof="source",
         message="ImportYumArtifactsGcsSource",
     )
-    error = proto.Field(
+    error: status_pb2.Status = proto.Field(
         proto.MESSAGE,
         number=2,
         message=status_pb2.Status,
@@ -153,19 +155,19 @@ class ImportYumArtifactsResponse(proto.Message):
     r"""The response message from importing YUM artifacts.
 
     Attributes:
-        yum_artifacts (Sequence[google.cloud.artifactregistry_v1beta2.types.YumArtifact]):
+        yum_artifacts (MutableSequence[google.cloud.artifactregistry_v1beta2.types.YumArtifact]):
             The yum artifacts imported.
-        errors (Sequence[google.cloud.artifactregistry_v1beta2.types.ImportYumArtifactsErrorInfo]):
+        errors (MutableSequence[google.cloud.artifactregistry_v1beta2.types.ImportYumArtifactsErrorInfo]):
             Detailed error info for artifacts that were
             not imported.
     """
 
-    yum_artifacts = proto.RepeatedField(
+    yum_artifacts: MutableSequence["YumArtifact"] = proto.RepeatedField(
         proto.MESSAGE,
         number=1,
         message="YumArtifact",
     )
-    errors = proto.RepeatedField(
+    errors: MutableSequence["ImportYumArtifactsErrorInfo"] = proto.RepeatedField(
         proto.MESSAGE,
         number=2,
         message="ImportYumArtifactsErrorInfo",
